/* artistParser.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef ARTISTPARSER_H
#define ARTISTPARSER_H

#include <string>
#include <vector>
#include <iostream.h>

// This class attempts to break up a formatted artist name into its
// constituent parts.  It tries to be reasonable intelligent in
// differentiating group names from individual artist names.

class ArtistParser {
public:
  enum Hint {
    H_none,
    H_individual,
    H_group
  };

  ArtistParser(const string &name, Hint hint = H_none);

  int find_and(int start, int num_words);
  int find_name_suffix(int start, int num_words);
  int find_group_prefix(int start, int num_words);

  string assemble_words(int start, int num_words);
  void get_group_name(int start, int num_words);
  void get_individual_name(int start, int num_words);

  void write(ostream &out) const;

  string _last_name, _first_name, _name_suffix;
  string _group_prefix, _group_name;

  string _name;
  vector<string> _words;
  vector<bool> _comma_flags;
  int _and_p;
  int _name_suffix_p;
  int _group_prefix_p;
};

inline ostream &operator << (ostream &out, const ArtistParser &ap) {
  ap.write(out);
  return out;
}

#endif
