/* pickOne.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef PICKONE_H
#define PICKONE_H

// This defines a combo-box-like widget that lets the user pick any
// one of a list of items, and returns the item code.  The item code
// is an integer, and the items are all strings. 

// It just manages the combo box interface a little more neatly when
// we want to use it to implement the "Pick one item from this list of
// things" interface.

#include <gtk--.h>

#include <map>

class PickOne : public Gtk_Combo {
public:
  typedef vector<pair<int, string> > Choices;

  PickOne();
  ~PickOne();

  void set_choices(const Choices &choices);
  void add_choice(int code, const string &text);
  void finish_choices();
  void remove_item(int item);
  void remove_item(Choices::iterator ci);

  void set_item(int item);
  void set_item(Choices::const_iterator ci);
  bool has_item();
  int get_item(int default_value = 0);

  Signal0 changed_item;

private:
  void entry_changed();

private:
  Choices _choices;

  bool _has_item;
  int _current_item;

  bool _internal_change;
};

#endif
