/* cdReader.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef CDREADER_H
#define CDREADER_H

// This module is only compiled if we actually have libcdaudio.
// Otherwise, we can't access the CD, and never mind.

#ifdef HAVE_CDAUDIO

#include "dataset.h"

#include <gtk--.h>
#include <string>
#include <iostream.h>
#include <sys/types.h>

extern "C" {
  #include <cdaudio.h>
}

class CDReader : public Gtk_Signal_Base {
public:
  CDReader(const Dataset &data, const string &device_name);
  ~CDReader();

  const string &get_device_name() const;
  bool query_cddb();

  bool has_disc() const;
  string get_cddb_id() const;
  int get_num_tracks() const;
  bool is_audio_track(int track_index) const;
  double get_track_length(int track_index) const;

  bool has_names() const;
  string get_title() const;
  string get_artist() const;
  string get_track_name(int track_index) const;
  string get_track_artist(int track_index) const;

  bool start_reading(int track_num, const string &filename);
  void stop_reading();
  bool is_reading();
  double get_reading_status();

  void eject();

  void write(ostream &out) const;

  Signal1<bool> done_reading;

private:
  void reading_pid_done(pid_t pid, bool normal_exit, int exit_status);

  bool _has_disc;
  bool _has_names;

  string _device_name;
  int _cd_desc;
  unsigned long _cddb_id;
  struct disc_info _disc_info;
  struct disc_data _disc_data;
  pid_t _read_pid;

  string _cd_rip_command_unexpanded;
  int _cdrom_type;
  int _cdrom_load_type;

  Dataset _data;
};

#endif // HAVE_CDAUDIO

#endif

